@@ -4,13 +4,9 @@
 extern crate test;
 #[macro_use(s)]
 extern crate ndarray;
-#[cfg(feature = "rblas")]
-extern crate rblas;
-#[cfg(feature = "rblas")]
-use rblas::matrix::Matrix;
 
 use ndarray::{
-    OwnedArray,
+    Array,
     Axis,
     Ix,
 };
@@ -21,7 +17,7 @@ use test::black_box;
 #[bench]
 fn map(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::linspace(0., 127., 128).into_shape((8, 16)).unwrap();
+    let a = Array::linspace(0., 127., 128).into_shape((8, 16)).unwrap();
     bench.iter(|| {
         a.map(|&x| 2. * x)
     });
@@ -30,7 +26,7 @@ fn map(bench: &mut test::Bencher)
 #[bench]
 fn iter_sum_1d_regular(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<i32, _>::zeros(64 * 64);
+    let a = Array::<i32, _>::zeros(64 * 64);
     let a = black_box(a);
     bench.iter(|| {
         let mut sum = 0;
@@ -45,7 +41,7 @@ fn iter_sum_1d_regular(bench: &mut test::Bencher)
 fn iter_sum_1d_raw(bench: &mut test::Bencher)
 {
     // this is autovectorized to death (= great performance)
-    let a = OwnedArray::<i32, _>::zeros(64 * 64);
+    let a = Array::<i32, _>::zeros(64 * 64);
     let a = black_box(a);
     bench.iter(|| {
         let mut sum = 0;
@@ -59,7 +55,7 @@ fn iter_sum_1d_raw(bench: &mut test::Bencher)
 #[bench]
 fn iter_sum_2d_regular(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<i32, _>::zeros((64, 64));
+    let a = Array::<i32, _>::zeros((64, 64));
     let a = black_box(a);
     bench.iter(|| {
         let mut sum = 0;
@@ -73,7 +69,7 @@ fn iter_sum_2d_regular(bench: &mut test::Bencher)
 #[bench]
 fn iter_sum_2d_by_row(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<i32, _>::zeros((64, 64));
+    let a = Array::<i32, _>::zeros((64, 64));
     let a = black_box(a);
     bench.iter(|| {
         let mut sum = 0;
@@ -90,7 +86,7 @@ fn iter_sum_2d_by_row(bench: &mut test::Bencher)
 fn iter_sum_2d_raw(bench: &mut test::Bencher)
 {
     // this is autovectorized to death (= great performance)
-    let a = OwnedArray::<i32, _>::zeros((64, 64));
+    let a = Array::<i32, _>::zeros((64, 64));
     let a = black_box(a);
     bench.iter(|| {
         let mut sum = 0;
@@ -104,7 +100,7 @@ fn iter_sum_2d_raw(bench: &mut test::Bencher)
 #[bench]
 fn iter_sum_2d_cutout(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<i32, _>::zeros((66, 66));
+    let a = Array::<i32, _>::zeros((66, 66));
     let av = a.slice(s![1..-1, 1..-1]);
     let a = black_box(av);
     bench.iter(|| {
@@ -119,7 +115,7 @@ fn iter_sum_2d_cutout(bench: &mut test::Bencher)
 #[bench]
 fn iter_sum_2d_cutout_by_row(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<i32, _>::zeros((66, 66));
+    let a = Array::<i32, _>::zeros((66, 66));
     let av = a.slice(s![1..-1, 1..-1]);
     let a = black_box(av);
     bench.iter(|| {
@@ -136,7 +132,7 @@ fn iter_sum_2d_cutout_by_row(bench: &mut test::Bencher)
 #[bench]
 fn iter_sum_2d_cutout_outer_iter(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<i32, _>::zeros((66, 66));
+    let a = Array::<i32, _>::zeros((66, 66));
     let av = a.slice(s![1..-1, 1..-1]);
     let a = black_box(av);
     bench.iter(|| {
@@ -153,7 +149,7 @@ fn iter_sum_2d_cutout_outer_iter(bench: &mut test::Bencher)
 #[bench]
 fn iter_sum_2d_transpose_regular(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<i32, _>::zeros((64, 64));
+    let mut a = Array::<i32, _>::zeros((64, 64));
     a.swap_axes(0, 1);
     let a = black_box(a);
     bench.iter(|| {
@@ -168,7 +164,7 @@ fn iter_sum_2d_transpose_regular(bench: &mut test::Bencher)
 #[bench]
 fn iter_sum_2d_transpose_by_row(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<i32, _>::zeros((64, 64));
+    let mut a = Array::<i32, _>::zeros((64, 64));
     a.swap_axes(0, 1);
     let a = black_box(a);
     bench.iter(|| {
@@ -185,7 +181,7 @@ fn iter_sum_2d_transpose_by_row(bench: &mut test::Bencher)
 #[bench]
 fn scalar_sum_2d_regular(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<i32, _>::zeros((64, 64));
+    let a = Array::<i32, _>::zeros((64, 64));
     let a = black_box(a);
     bench.iter(|| {
         a.scalar_sum()
@@ -195,7 +191,7 @@ fn scalar_sum_2d_regular(bench: &mut test::Bencher)
 #[bench]
 fn scalar_sum_2d_cutout(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<i32, _>::zeros((66, 66));
+    let a = Array::<i32, _>::zeros((66, 66));
     let av = a.slice(s![1..-1, 1..-1]);
     let a = black_box(av);
     bench.iter(|| {
@@ -206,7 +202,7 @@ fn scalar_sum_2d_cutout(bench: &mut test::Bencher)
 #[bench]
 fn scalar_sum_2d_float(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros((64, 64));
+    let a = Array::<f32, _>::zeros((64, 64));
     let a = black_box(a.view());
     bench.iter(|| {
         a.scalar_sum()
@@ -216,7 +212,7 @@ fn scalar_sum_2d_float(bench: &mut test::Bencher)
 #[bench]
 fn scalar_sum_2d_float_cutout(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros((66, 66));
+    let a = Array::<f32, _>::zeros((66, 66));
     let av = a.slice(s![1..-1, 1..-1]);
     let a = black_box(av);
     bench.iter(|| {
@@ -227,19 +223,19 @@ fn scalar_sum_2d_float_cutout(bench: &mut test::Bencher)
 #[bench]
 fn add_2d_regular(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<i32, _>::zeros((64, 64));
-    let b = OwnedArray::<i32, _>::zeros((64, 64));
+    let mut a = Array::<i32, _>::zeros((64, 64));
+    let b = Array::<i32, _>::zeros((64, 64));
     let bv = b.view();
     bench.iter(|| {
-        a.iadd(&bv);
+        a += &bv;
     });
 }
 
 #[bench]
 fn add_2d_assign_ops(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<i32, _>::zeros((64, 64));
-    let b = OwnedArray::<i32, _>::zeros((64, 64));
+    let mut a = Array::<i32, _>::zeros((64, 64));
+    let b = Array::<i32, _>::zeros((64, 64));
     let bv = b.view();
     bench.iter(|| {
         let mut x = a.view_mut();
@@ -251,40 +247,40 @@ fn add_2d_assign_ops(bench: &mut test::Bencher)
 #[bench]
 fn add_2d_cutout(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<i32, _>::zeros((66, 66));
+    let mut a = Array::<i32, _>::zeros((66, 66));
     let mut acut = a.slice_mut(s![1..-1, 1..-1]);
-    let b = OwnedArray::<i32, _>::zeros((64, 64));
+    let b = Array::<i32, _>::zeros((64, 64));
     let bv = b.view();
     bench.iter(|| {
-        acut.iadd(&bv);
+        acut += &bv;
     });
 }
 
 #[bench]
 fn add_2d_broadcast_1_to_2(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<i32, _>::zeros((64, 64));
-    let b = OwnedArray::<i32, _>::zeros(64);
+    let mut a = Array::<i32, _>::zeros((64, 64));
+    let b = Array::<i32, _>::zeros(64);
     let bv = b.view();
     bench.iter(|| {
-        a.iadd(&bv);
+        a += &bv;
     });
 }
 
 #[bench]
 fn add_2d_broadcast_0_to_2(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<i32, _>::zeros((64, 64));
-    let b = OwnedArray::<i32, _>::zeros(());
+    let mut a = Array::<i32, _>::zeros((64, 64));
+    let b = Array::<i32, _>::zeros(());
     let bv = b.view();
     bench.iter(|| {
-        a.iadd(&bv);
+        a += &bv;
     });
 }
 
 #[bench]
 fn scalar_toowned(bench: &mut test::Bencher) {
-    let a = OwnedArray::<f32, _>::zeros((64, 64));
+    let a = Array::<f32, _>::zeros((64, 64));
     bench.iter(|| {
         a.to_owned()
     });
@@ -292,7 +288,7 @@ fn scalar_toowned(bench: &mut test::Bencher) {
 
 #[bench]
 fn scalar_add_1(bench: &mut test::Bencher) {
-    let a = OwnedArray::<f32, _>::zeros((64, 64));
+    let a = Array::<f32, _>::zeros((64, 64));
     let n = 1.;
     bench.iter(|| {
         &a + n
@@ -301,7 +297,7 @@ fn scalar_add_1(bench: &mut test::Bencher) {
 
 #[bench]
 fn scalar_add_2(bench: &mut test::Bencher) {
-    let a = OwnedArray::<f32, _>::zeros((64, 64));
+    let a = Array::<f32, _>::zeros((64, 64));
     let n = 1.;
     bench.iter(|| {
         n + &a
@@ -310,7 +306,7 @@ fn scalar_add_2(bench: &mut test::Bencher) {
 
 #[bench]
 fn scalar_sub_1(bench: &mut test::Bencher) {
-    let a = OwnedArray::<f32, _>::zeros((64, 64));
+    let a = Array::<f32, _>::zeros((64, 64));
     let n = 1.;
     bench.iter(|| {
         &a - n
@@ -319,7 +315,7 @@ fn scalar_sub_1(bench: &mut test::Bencher) {
 
 #[bench]
 fn scalar_sub_2(bench: &mut test::Bencher) {
-    let a = OwnedArray::<f32, _>::zeros((64, 64));
+    let a = Array::<f32, _>::zeros((64, 64));
     let n = 1.;
     bench.iter(|| {
         n - &a
@@ -331,50 +327,33 @@ fn scalar_sub_2(bench: &mut test::Bencher) {
 #[bench]
 fn add_2d_0_to_2_iadd_scalar(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<i32, _>::zeros((64, 64));
+    let mut a = Array::<i32, _>::zeros((64, 64));
     let n = black_box(0);
     bench.iter(|| {
-        a.iadd_scalar(&n);
+        a += n;
     });
 }
 
 #[bench]
 fn add_2d_transposed(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<i32, _>::zeros((64, 64));
+    let mut a = Array::<i32, _>::zeros((64, 64));
     a.swap_axes(0, 1);
-    let b = OwnedArray::<i32, _>::zeros((64, 64));
+    let b = Array::<i32, _>::zeros((64, 64));
     let bv = b.view();
     bench.iter(|| {
-        a.iadd(&bv);
+        a += &bv;
     });
 }
 
 #[bench]
 fn add_2d_f32_regular(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<f32, _>::zeros((64, 64));
-    let b = OwnedArray::<f32, _>::zeros((64, 64));
+    let mut a = Array::<f32, _>::zeros((64, 64));
+    let b = Array::<f32, _>::zeros((64, 64));
     let bv = b.view();
     bench.iter(|| {
-        a.iadd(&bv);
-    });
-}
-
-#[cfg(feature = "rblas")]
-#[bench]
-fn add_2d_f32_blas(bench: &mut test::Bencher)
-{
-    use rblas::Axpy;
-    use rblas::attribute::Transpose;
-    use ndarray::blas::AsBlas;
-    let mut a = OwnedArray::<f32, _>::zeros((64, 64));
-    let b = OwnedArray::<f32, _>::zeros((64, 64));
-    let len = a.len();
-    let mut av = a.view_mut().into_shape(len).unwrap();
-    let bv = b.view().into_shape(len).unwrap();
-    bench.iter(|| {
-        f32::axpy(&1., &bv.bv(), &mut av.bvm());
+        a += &bv;
     });
 }
 
@@ -383,8 +362,8 @@ const ADD1D_SIZE: usize = 64 * 64;
 #[bench]
 fn add_1d_regular(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<f32, _>::zeros(ADD1D_SIZE);
-    let b = OwnedArray::<f32, _>::zeros(a.dim());
+    let mut a = Array::<f32, _>::zeros(ADD1D_SIZE);
+    let b = Array::<f32, _>::zeros(a.dim());
     bench.iter(|| {
         a += &b;
     });
@@ -393,9 +372,9 @@ fn add_1d_regular(bench: &mut test::Bencher)
 #[bench]
 fn add_1d_strided(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<f32, _>::zeros(ADD1D_SIZE * 2);
+    let mut a = Array::<f32, _>::zeros(ADD1D_SIZE * 2);
     let mut av = a.slice_mut(s![..;2]);
-    let b = OwnedArray::<f32, _>::zeros(av.dim());
+    let b = Array::<f32, _>::zeros(av.dim());
     bench.iter(|| {
         av += &b;
     });
@@ -404,36 +383,18 @@ fn add_1d_strided(bench: &mut test::Bencher)
 #[bench]
 fn scaled_add_2d_f32_regular(bench: &mut test::Bencher)
 {
-    let mut av = OwnedArray::<f32, _>::zeros((64, 64));
-    let bv = OwnedArray::<f32, _>::zeros((64, 64));
+    let mut av = Array::<f32, _>::zeros((64, 64));
+    let bv = Array::<f32, _>::zeros((64, 64));
     let scalar = 3.1415926535;
     bench.iter(|| {
         av.scaled_add(scalar, &bv);
     });
 }
 
-#[cfg(feature = "rblas")]
-#[bench]
-fn scaled_add_2d_f32_blas(bench: &mut test::Bencher)
-{
-    use rblas::Axpy;
-    use rblas::attribute::Transpose;
-    use ndarray::blas::AsBlas;
-    let mut a = OwnedArray::<f32, _>::zeros((64, 64));
-    let b = OwnedArray::<f32, _>::zeros((64, 64));
-    let scalar = 3.1415926535;
-    let len = a.len();
-    let mut av = a.view_mut().into_shape(len).unwrap();
-    let bv = b.view().into_shape(len).unwrap();
-    bench.iter(|| {
-        f32::axpy(&scalar, &bv.bv(), &mut av.bvm());
-    });
-}
-
 #[bench]
 fn assign_scalar_2d_corder(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::zeros((64, 64));
+    let a = Array::zeros((64, 64));
     let mut a = black_box(a);
     let s = 3.;
     bench.iter(move || a.assign_scalar(&s))
@@ -442,7 +403,7 @@ fn assign_scalar_2d_corder(bench: &mut test::Bencher)
 #[bench]
 fn assign_scalar_2d_cutout(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::zeros((66, 66));
+    let mut a = Array::zeros((66, 66));
     let a = a.slice_mut(s![1..-1, 1..-1]);
     let mut a = black_box(a);
     let s = 3.;
@@ -452,7 +413,7 @@ fn assign_scalar_2d_cutout(bench: &mut test::Bencher)
 #[bench]
 fn assign_scalar_2d_forder(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::zeros((64, 64));
+    let mut a = Array::zeros((64, 64));
     a.swap_axes(0, 1);
     let mut a = black_box(a);
     let s = 3.;
@@ -462,7 +423,7 @@ fn assign_scalar_2d_forder(bench: &mut test::Bencher)
 #[bench]
 fn assign_zero_2d_corder(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::zeros((64, 64));
+    let a = Array::zeros((64, 64));
     let mut a = black_box(a);
     bench.iter(|| a.assign_scalar(&0.))
 }
@@ -470,7 +431,7 @@ fn assign_zero_2d_corder(bench: &mut test::Bencher)
 #[bench]
 fn assign_zero_2d_cutout(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::zeros((66, 66));
+    let mut a = Array::zeros((66, 66));
     let a = a.slice_mut(s![1..-1, 1..-1]);
     let mut a = black_box(a);
     bench.iter(|| a.assign_scalar(&0.))
@@ -479,7 +440,7 @@ fn assign_zero_2d_cutout(bench: &mut test::Bencher)
 #[bench]
 fn assign_zero_2d_forder(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::zeros((64, 64));
+    let mut a = Array::zeros((64, 64));
     a.swap_axes(0, 1);
     let mut a = black_box(a);
     bench.iter(|| a.assign_scalar(&0.))
@@ -488,14 +449,14 @@ fn assign_zero_2d_forder(bench: &mut test::Bencher)
 #[bench]
 fn bench_iter_diag(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros((1024, 1024));
+    let a = Array::<f32, _>::zeros((1024, 1024));
     bench.iter(|| for elt in a.diag() { black_box(elt); })
 }
 
 #[bench]
 fn bench_row_iter(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros((1024, 1024));
+    let a = Array::<f32, _>::zeros((1024, 1024));
     let it = a.row(17);
     bench.iter(|| for elt in it.clone() { black_box(elt); })
 }
@@ -503,7 +464,7 @@ fn bench_row_iter(bench: &mut test::Bencher)
 #[bench]
 fn bench_col_iter(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros((1024, 1024));
+    let a = Array::<f32, _>::zeros((1024, 1024));
     let it = a.column(17);
     bench.iter(|| for elt in it.clone() { black_box(elt); })
 }
@@ -512,16 +473,16 @@ macro_rules! mat_mul {
     ($modname:ident, $ty:ident, $(($name:ident, $m:expr, $n:expr, $k:expr))+) => {
         mod $modname {
             use test::{black_box, Bencher};
-            use ndarray::OwnedArray;
+            use ndarray::Array;
             $(
             #[bench]
             fn $name(bench: &mut Bencher)
             {
-                let a = OwnedArray::<$ty, _>::zeros(($m, $n));
-                let b = OwnedArray::<$ty, _>::zeros(($n, $k));
+                let a = Array::<$ty, _>::zeros(($m, $n));
+                let b = Array::<$ty, _>::zeros(($n, $k));
                 let a = black_box(a.view());
                 let b = black_box(b.view());
-                bench.iter(|| a.mat_mul(&b));
+                bench.iter(|| a.dot(&b));
             }
             )+
         }
@@ -567,30 +528,10 @@ mat_mul!{mat_mul_i32, i32,
     (m127, 127, 127, 127)
 }
 
-#[cfg(feature = "rblas")]
-#[bench]
-fn bench_mat_mul_rblas_64(bench: &mut test::Bencher)
-{
-    use rblas::Gemm;
-    use rblas::attribute::Transpose;
-    use ndarray::blas::AsBlas;
-
-    let a = OwnedArray::<f32, _>::zeros((64, 64));
-    let b = OwnedArray::<f32, _>::zeros((64, 64));
-    let mut c = OwnedArray::<f32, _>::zeros((64, 64));
-    bench.iter(|| {
-        // C ← α AB + β C
-        f32::gemm(&1.,
-                  Transpose::NoTrans, &a.bv(),
-                  Transpose::NoTrans, &b.bv(),
-                  &1., &mut c.bvm());
-    });
-}
-
 #[bench]
 fn create_iter_4d(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::from_elem((4, 5, 3, 2), 1.0);
+    let mut a = Array::from_elem((4, 5, 3, 2), 1.0);
     a.swap_axes(0, 1);
     a.swap_axes(2, 1);
     let v = black_box(a.view());
@@ -603,14 +544,14 @@ fn create_iter_4d(bench: &mut test::Bencher)
 #[bench]
 fn bench_to_owned_n(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros((32, 32));
+    let a = Array::<f32, _>::zeros((32, 32));
     bench.iter(|| a.to_owned());
 }
 
 #[bench]
 fn bench_to_owned_t(bench: &mut test::Bencher)
 {
-    let mut a = OwnedArray::<f32, _>::zeros((32, 32));
+    let mut a = Array::<f32, _>::zeros((32, 32));
     a.swap_axes(0, 1);
     bench.iter(|| a.to_owned());
 }
@@ -618,56 +559,56 @@ fn bench_to_owned_t(bench: &mut test::Bencher)
 #[bench]
 fn equality_i32(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<i32, _>::zeros((64, 64));
-    let b = OwnedArray::<i32, _>::zeros((64, 64));
+    let a = Array::<i32, _>::zeros((64, 64));
+    let b = Array::<i32, _>::zeros((64, 64));
     bench.iter(|| a == b);
 }
 
 #[bench]
 fn equality_f32(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros((64, 64));
-    let b = OwnedArray::<f32, _>::zeros((64, 64));
+    let a = Array::<f32, _>::zeros((64, 64));
+    let b = Array::<f32, _>::zeros((64, 64));
     bench.iter(|| a == b);
 }
 
 #[bench]
 fn dot_f32_16(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros(16);
-    let b = OwnedArray::<f32, _>::zeros(16);
+    let a = Array::<f32, _>::zeros(16);
+    let b = Array::<f32, _>::zeros(16);
     bench.iter(|| a.dot(&b));
 }
 
 #[bench]
 fn dot_f32_20(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros(20);
-    let b = OwnedArray::<f32, _>::zeros(20);
+    let a = Array::<f32, _>::zeros(20);
+    let b = Array::<f32, _>::zeros(20);
     bench.iter(|| a.dot(&b));
 }
 
 #[bench]
 fn dot_f32_32(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros(32);
-    let b = OwnedArray::<f32, _>::zeros(32);
+    let a = Array::<f32, _>::zeros(32);
+    let b = Array::<f32, _>::zeros(32);
     bench.iter(|| a.dot(&b));
 }
 
 #[bench]
 fn dot_f32_256(bench: &mut test::Bencher)
 {
-    let a = OwnedArray::<f32, _>::zeros(256);
-    let b = OwnedArray::<f32, _>::zeros(256);
+    let a = Array::<f32, _>::zeros(256);
+    let b = Array::<f32, _>::zeros(256);
     bench.iter(|| a.dot(&b));
 }
 
 #[bench]
 fn dot_f32_1024(bench: &mut test::Bencher)
 {
-    let av = OwnedArray::<f32, _>::zeros(1024);
-    let bv = OwnedArray::<f32, _>::zeros(1024);
+    let av = Array::<f32, _>::zeros(1024);
+    let bv = Array::<f32, _>::zeros(1024);
     bench.iter(|| {
         av.dot(&bv)
     });
@@ -677,8 +618,8 @@ fn dot_f32_1024(bench: &mut test::Bencher)
 fn dot_f32_10e6(bench: &mut test::Bencher)
 {
     let n = 1_000_000;
-    let av = OwnedArray::<f32, _>::zeros(n);
-    let bv = OwnedArray::<f32, _>::zeros(n);
+    let av = Array::<f32, _>::zeros(n);
+    let bv = Array::<f32, _>::zeros(n);
     bench.iter(|| {
         av.dot(&bv)
     });
@@ -689,9 +630,9 @@ fn dot_extended(bench: &mut test::Bencher) {
     let m = 10;
     let n = 33;
     let k = 10;
-    let av = OwnedArray::<f32, _>::zeros((m, n));
-    let bv = OwnedArray::<f32, _>::zeros((n, k));
-    let mut res = OwnedArray::<f32, _>::zeros((m, k));
+    let av = Array::<f32, _>::zeros((m, n));
+    let bv = Array::<f32, _>::zeros((n, k));
+    let mut res = Array::<f32, _>::zeros((m, k));
     // make a manual simple matrix multiply to test
     bench.iter(|| {
         for i in 0..m {
@@ -706,9 +647,9 @@ fn dot_extended(bench: &mut test::Bencher) {
 
 const MEAN_SUM_N: usize = 127;
 
-fn range_mat(m: Ix, n: Ix) -> OwnedArray<f32, (Ix, Ix)> {
+fn range_mat(m: Ix, n: Ix) -> Array<f32, (Ix, Ix)> {
     assert!(m * n != 0);
-    OwnedArray::linspace(0., (m * n - 1) as f32, m * n).into_shape((m, n)).unwrap()
+    Array::linspace(0., (m * n - 1) as f32, m * n).into_shape((m, n)).unwrap()
 }
 
 #[bench]
